#!/usr/bin/env perl
use strict;
use warnings;

=head1 NAME

options - Test file for ack command line options

=cut

[abc]

@Q_fields = split(/\b(?:a|b|c)\b/)

__DATA__
THIS IS ALL IN UPPER CASE

this is a word here
notawordhere
